#### Atomic levels

$\text{3S} _{1/2}$, $\text{3P} _{3/2}$

#### Pump transitions

1. $\text{3S} _{1/2}\to \text{3P} _{3/2}$

#### Transition wavelengths

- $\text{3P} _{3/2}\to \text{3S} _{1/2}$: 589.158 nm

#### Substructure

- Hyperfine structure included
- Zeeman structure included
- 24 total sublevels

#### Density matrix elements

- All populations included
- All Zeeman coherences (between same level and same F) included
- All hyperfine coherences (between same level and different F) neglected
- Optical coherences (between different levels) included for pump transitions only
- 374 total density matrix elements

#### Input parameters

- BeamTransitRatePerS
- BFieldG
- MagneticAzimuthDegrees
- MagneticZenithDegrees
- RecoilParameter
- SDampingCollisionRatePerS
- TemperatureK
- VccRatePerS
- DetuningHz1
- EllipticityDegrees1
- IntensitySI1
- LaserWidthHz1
- PolarizationAngleDegrees1